Package: eRm
Type: Package
Title: Extended Rasch Modeling
Version: 1.0-10
Date: 2025-05-27
Authors@R: c(person(given="Patrick", family="Mair", email="mair@fas.harvard.edu", role=c("cre","aut")),
             person(given="Thomas", family="Rusch", email="thomas.rusch@wu.ac.at", role="aut"),
             person(given="Reinhold", family="Hatzinger", role="aut"),
             person(given=c("Marco", "J."), family="Maier", role="aut"),
             person(given="Rudolf", family="Debelak", email="rudolf.debelak@psychologie.uzh.ch", role="ctb"))
Description: Fits Rasch models (RM), linear logistic test models (LLTM), rating scale model (RSM), linear rating scale models (LRSM), partial credit models (PCM), and linear partial credit models (LPCM).  Missing values are allowed in the data matrix.  Additional features are the ML estimation of the person parameters, Andersen's LR-test, item-specific Wald test, Martin-Loef-Test, nonparametric Monte-Carlo Tests, itemfit and personfit statistics including infit and outfit measures, ICC and other plots, automated stepwise item elimination, simulation module for various binary data matrices.
License: GPL-3
Imports: graphics, grDevices, stats, methods, MASS, splines, Matrix,
        lattice, colorspace, psych
Depends: R (>= 3.5.0)
Encoding: UTF-8
LazyData: yes
LazyLoad: yes
ByteCompile: yes
NeedsCompilation: yes
Packaged: 2025-05-27 22:35:33 UTC; patrick
Author: Patrick Mair [cre, aut],
  Thomas Rusch [aut],
  Reinhold Hatzinger [aut],
  Marco J. Maier [aut],
  Rudolf Debelak [ctb]
Maintainer: Patrick Mair <mair@fas.harvard.edu>
Repository: CRAN
Date/Publication: 2025-05-27 23:00:18 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 00:33:55 UTC; unix
Archs: eRm.so.dSYM
